@@ -99,7 +99,7 @@ echo "#########################################################################"
 ################################################################################
 if [[ $(id -u) -ne 0 ]]; then
     echo ">>>>>> Re-launching as sudo <<<<<<"
-    exec sudo /bin/bash -c "$(printf '%q ' "$BASH_SOURCE" "$@")"
+    exec sudo -E /bin/bash -c "$(printf '%q ' "$BASH_SOURCE" "$@")"
 fi
 
 ################################################################################
