@@ -34,7 +34,7 @@ echo "Build Environment Script"
 ################################################################################
 if [[ $(id -u) -ne 0 ]]; then
     echo ">>>>>> Re-launching as sudo <<<<<<"
-    exec sudo /bin/bash -c "$(printf '%q ' "$BASH_SOURCE" "$@")"
+    exec sudo -E /bin/bash -c "$(printf '%q ' "$BASH_SOURCE" "$@")"
 fi
 
 ################################################################################
@@ -58,8 +58,8 @@ MACOSX_DEPLOYMENT_TARGET=10.15
 export MACOSX_DEPLOYMENT_TARGET
 
 # Versions we're going to install
-PY_VERSION=3.7
-PY_DOT_VERSION=3.7.12
+PY_VERSION=3.9
+PY_DOT_VERSION=3.9.12
 ZMQ_VERSION=4.3.4
 LIBSODIUM_VERSION=1.0.18
 
