@@ -189,11 +189,7 @@ class BuildoutTestCase(Base):
         ret2 = buildout._salt_callback(callback2)(2, b=6)
         self.assertEqual(ret2["status"], False)
         self.assertTrue(ret2["logs_by_level"]["error"][0].startswith("Traceback"))
-        self.assertTrue(
-            "We did not get any "
-            "expectable answer "
-            "from buildout" in ret2["comment"]
-        )
+        self.assertTrue("Unexpected response from buildout" in ret2["comment"])
         self.assertEqual(ret2["out"], None)
         for l in buildout.LOG.levels:
             self.assertTrue(0 == len(buildout.LOG.by_level[l]))
@@ -291,7 +287,7 @@ class BuildoutTestCase(Base):
     @pytest.mark.slow_test
     def test__find_cfgs(self):
         result = sorted(
-            [a.replace(self.root, "") for a in buildout._find_cfgs(self.root)]
+            a.replace(self.root, "") for a in buildout._find_cfgs(self.root)
         )
         assertlist = sorted(
             [
@@ -357,7 +353,7 @@ class BuildoutOnlineTestCase(Base):
             )
         except subprocess.CalledProcessError:
             subprocess.check_call(
-                [salt.utils.path.which_bin(KNOWN_VIRTUALENV_BINARY_NAMES), cls.ppy.dis]
+                [salt.utils.path.which_bin(KNOWN_VIRTUALENV_BINARY_NAMES), cls.ppy_dis]
             )
 
             url = (
@@ -365,7 +361,8 @@ class BuildoutOnlineTestCase(Base):
                 "/d/distribute/distribute-0.6.43.tar.gz"
             )
             download_to(
-                url, os.path.join(cls.ppy_dis, "distribute-0.6.43.tar.gz"),
+                url,
+                os.path.join(cls.ppy_dis, "distribute-0.6.43.tar.gz"),
             )
 
             subprocess.check_call(
@@ -404,7 +401,7 @@ class BuildoutOnlineTestCase(Base):
                 ]
             )
 
-    @skipIf(True, "TODO this test should probably be fixed")
+    @pytest.mark.skip(reason="TODO this test should probably be fixed")
     def test_buildout_bootstrap(self):
         b_dir = os.path.join(self.tdir, "b")
         bd_dir = os.path.join(self.tdir, "b", "bdistribute")
@@ -458,7 +455,8 @@ class BuildoutOnlineTestCase(Base):
     def test_run_buildout(self):
         if salt.modules.virtualenv_mod.virtualenv_ver(self.ppy_st) >= (20, 0, 0):
             self.skipTest(
-                "Skiping until upstream resolved https://github.com/pypa/virtualenv/issues/1715"
+                "Skiping until upstream resolved"
+                " https://github.com/pypa/virtualenv/issues/1715"
             )
 
         b_dir = os.path.join(self.tdir, "b")
@@ -473,7 +471,8 @@ class BuildoutOnlineTestCase(Base):
     def test_buildout(self):
         if salt.modules.virtualenv_mod.virtualenv_ver(self.ppy_st) >= (20, 0, 0):
             self.skipTest(
-                "Skiping until upstream resolved https://github.com/pypa/virtualenv/issues/1715"
+                "Skiping until upstream resolved"
+                " https://github.com/pypa/virtualenv/issues/1715"
             )
 
         b_dir = os.path.join(self.tdir, "b")
